import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import type { OperationOptions } from "retry";
import type { RequestInit } from "node-fetch";
export declare namespace Orders {
    type ErrorResponse = {
        type: string;
        title?: string;
        detail?: string;
        instance?: string;
    } & {
        [key: string]: any;
    };
    type PaymentTransactionUpdateRequest = {} & {
        [key: string]: any;
    };
    type PaymentInstrumentUpdateRequest = {} & {
        [key: string]: any;
    };
    type OrderPaymentStatusUpdateRequest = {
        status: string;
    };
    type PaymentCard = {
        cardType?: string;
        creditCardExpired?: boolean;
        creditCardToken?: string;
        expirationMonth?: number;
        expirationYear?: number;
        holder?: string;
        issueNumber?: string;
        maskedNumber?: string;
        numberLastDigits?: string;
        validFromMonth?: number;
        validFromYear?: number;
    };
    type ShippingItem = {
        basePrice?: number;
        grossPrice?: number;
        itemText?: string;
        netPrice?: number;
        tax?: number;
        taxBasis?: number;
        adjustedTax?: number;
        itemId?: string;
        priceAdjustments?: Array<PriceAdjustment>;
        priceAfterItemDiscount?: number;
        shipmentId?: string;
        taxRate: number;
        type?: string;
    } & {
        [key: string]: any;
    };
    type Discount = {
        amount?: number;
        percentage?: number;
        priceBookId?: string;
        type: string;
    };
    type OrderConfirmationStatusUpdateRequest = {
        status: string;
    };
    type Address = {
        address1?: string;
        address2?: string;
        city?: string;
        companyName?: string;
        countryCode?: string;
        firstName?: string;
        fullName?: string;
        jobTitle?: string;
        lastName?: string;
        phone?: string;
        postBox?: string;
        postalCode?: string;
        salutation?: string;
        secondName?: string;
        stateCode?: string;
        suffix?: string;
        suite?: string;
        title?: string;
    } & {
        [key: string]: any;
    };
    type CouponItem = {
        code?: string;
        couponItemId?: string;
        statusCode?: string;
        valid?: boolean;
    };
    type OrdersResponse = {
        data: Array<Order>;
    };
    type ShippingMethodReference = {
        id?: string;
    };
    type ProductItem = {
        basePrice?: number;
        grossPrice?: number;
        itemText?: string;
        netPrice?: number;
        tax?: number;
        taxBasis?: number;
        adjustedTax?: number;
        bonusDiscountLineItemId?: string;
        bonusProductLineItem?: boolean;
        brand?: string;
        bundledProductItems?: Array<ProductItem>;
        externalLineItemStatus?: string;
        externalLineItemText?: string;
        gift?: boolean;
        giftMessage?: string;
        inventoryId?: string;
        itemId?: string;
        minOrderQuantity?: number;
        optionItems?: Array<OptionItem>;
        position?: number;
        priceAdjustments?: Array<PriceAdjustment>;
        priceAfterItemDiscount?: number;
        priceAfterOrderDiscount?: number;
        productId: string;
        productListItem?: ProductListItemReference;
        productName?: string;
        quantity?: number;
        shipmentId: string;
        shippingItemId?: string;
        stepQuantity?: number;
        taxRate: number;
    } & {
        [key: string]: any;
    };
    type BonusDiscountLineItem = {
        bonusProducts?: Array<ProductReference>;
        couponCode?: string;
        id?: string;
        maxBonusItems?: number;
        promotionId?: string;
    } & {
        [key: string]: any;
    };
    type ShippingAddressUpdateRequest = {} & {
        [key: string]: any;
    };
    type Shipment = {
        adjustedMerchandizeTotalTax?: number;
        adjustedShippingTotalTax?: number;
        gift?: boolean;
        giftMessage?: string;
        merchandizeTotalTax?: number;
        productSubTotal?: number;
        productTotal?: number;
        shipmentId: string;
        shipmentNo: string;
        shipmentTotal?: number;
        shippingAddress?: Address;
        shippingMethod?: ShippingMethodReference;
        shippingStatus?: string;
        shippingTotal?: number;
        shippingTotalTax?: number;
        taxTotal?: number;
        trackingNumber?: string;
    } & {
        [key: string]: any;
    };
    type CustomerInfo = {
        customerId?: string;
        customerName?: string;
        customerNo?: string;
        email?: string;
        guest?: boolean;
    };
    type PriceAdjustment = {
        basePrice?: number;
        grossPrice?: number;
        itemText?: string;
        netPrice?: number;
        tax?: number;
        taxBasis?: number;
        abTestSegment?: ABTestSegment;
        appliedDiscount?: Discount;
        campaignId?: string;
        couponCode?: string;
        createdBy?: string;
        creationDate?: any;
        custom?: boolean;
        lastModified?: any;
        manual?: boolean;
        priceAdjustmentId?: string;
        promotionId: string;
        reasonCode?: string;
    } & {
        [key: string]: any;
    };
    type OrderExternalStatusUpdateRequest = {
        status: string;
    };
    type OptionItem = {
        basePrice?: number;
        grossPrice?: number;
        gift?: boolean;
        itemText?: string;
        netPrice?: number;
        tax?: number;
        taxBasis?: number;
        optionId?: string;
        optionValueId?: string;
        priceAdjustments?: Array<PriceAdjustment>;
        productId: string;
    } & {
        [key: string]: any;
    };
    type CreateOrderPaymentInstrument = {
        paymentMethodId: string;
        paymentTransaction?: CreateOrderPaymentTransaction;
    } & {
        [key: string]: any;
    };
    type OrderShippingStatusUpdateRequest = {
        status: string;
    };
    type OrderUpdateRequest = {} & {
        [key: string]: any;
    };
    type ABTestSegment = {
        testId: string;
        segmentId: string;
    };
    type CreateOrderPriceAdjustment = {
        amount?: number;
        basePrice?: number;
        grossPrice: number;
        itemText?: string;
        netPrice: number;
        reasonCode?: string;
        tax: number;
        taxBasis?: number;
    } & {
        [key: string]: any;
    };
    type OrderNote = {
        createdBy?: string;
        creationDate?: any;
        subject?: string;
        text?: string;
    };
    type PaymentInstrument = {
        bankRoutingNumber?: string;
        maskedGiftCertificateCode?: string;
        paymentCard?: PaymentCard;
        paymentInstrumentId?: string;
        paymentMethodId?: string;
        paymentTransaction?: PaymentTransaction;
    } & {
        [key: string]: any;
    };
    type OrderExportStatusUpdateRequest = {
        status: string;
    };
    type OrderStatusUpdateRequest = {
        status: string;
    };
    type CreateOrderPaymentTransaction = {
        amount: number;
        authorizationStatus?: Status;
        transactionId: string;
    } & {
        [key: string]: any;
    };
    type CreateOrderProductItems = {
        basePrice: number;
        brand?: string;
        grossPrice: number;
        itemText?: string;
        netPrice: number;
        optionItems?: Array<CreateOrderOptionItem>;
        priceAdjustments?: Array<CreateOrderPriceAdjustment>;
        productId: string;
        productName?: string;
        quantity: number;
        shipmentId: string;
        tax: number;
        taxBasis?: number;
        taxRate?: number;
    } & {
        [key: string]: any;
    };
    type ProductReference = {
        productId?: string;
        productName?: string;
    };
    type CreateOrderShipment = {
        shipmentId: string;
        shippingMethod: string;
        shippingAddress: Address;
        shippingTotal: number;
        taxTotal: number;
    };
    type GiftCertificateItem = {
        basePrice?: number;
        grossPrice?: number;
        itemText?: string;
        netPrice?: number;
        tax?: number;
        taxBasis?: number;
        giftCertificateMerchantId?: string;
        giftCertificateItemId?: string;
        message?: string;
        recipientEmail?: string;
        recipientName?: string;
        senderName?: string;
        shipmentId?: string;
    } & {
        [key: string]: any;
    };
    type PaymentTransaction = {
        amount?: number;
        authorizationStatus?: Status;
        transactionId?: string;
    } & {
        [key: string]: any;
    };
    type Order = {
        adjustedMerchandizeTotalTax?: number;
        adjustedShippingTotalTax?: number;
        affiliatePartnerId?: string;
        affiliatePartnerName?: string;
        billingAddress?: Address;
        bonusDiscountLineItems?: Array<BonusDiscountLineItem>;
        businessType?: string;
        cancelCode?: string;
        cancelDescription?: string;
        channelType?: string;
        confirmationStatus?: string;
        couponItems?: Array<CouponItem>;
        createdBy?: string;
        creationDate?: any;
        currency?: string;
        customerInfo?: CustomerInfo;
        customerLocale?: string;
        customerOrderReference?: string;
        exportStatus?: string;
        externalOrderNo?: string;
        externalOrderStatus?: string;
        externalOrderText?: string;
        giftCertificateItems?: Array<GiftCertificateItem>;
        globalPartyId?: string;
        invoiceNo?: string;
        lastModified?: any;
        merchandizeTotalTax?: number;
        notes?: Array<OrderNote>;
        orderNo: string;
        orderPriceAdjustments?: Array<PriceAdjustment>;
        orderTotal?: number;
        paymentInstruments?: Array<PaymentInstrument>;
        paymentStatus?: string;
        placeDate?: any;
        productItems?: Array<ProductItem>;
        productSubTotal?: number;
        productTotal?: number;
        remoteHost?: string;
        shipments?: Array<Shipment>;
        shippingItems?: Array<ShippingItem>;
        shippingStatus?: string;
        shippingTotal?: number;
        shippingTotalTax?: number;
        siteId?: string;
        sourceCode?: string;
        sourceCodeGroupId?: string;
        status?: string;
        taxTotal?: number;
        taxation?: string;
    } & {
        [key: string]: any;
    };
    type CreateOrderRequest = {
        billingAddress: Address;
        businessType?: string;
        channelType?: string;
        currency: string;
        customerLocale?: string;
        orderNo?: string;
        orderPriceAdjustments?: Array<CreateOrderPriceAdjustment>;
        orderTotal: number;
        paymentInstruments: Array<CreateOrderPaymentInstrument>;
        paymentStatus?: string;
        productItems: Array<CreateOrderProductItems>;
        shipments: Array<CreateOrderShipment>;
        taxTotal: number;
    } & {
        [key: string]: any;
    };
    type ProductListReference = {
        description?: string;
        name?: string;
        public?: boolean;
        type?: string;
    };
    type CreateOrderOptionItem = {
        basePrice: number;
        grossPrice: number;
        itemText?: string;
        netPrice: number;
        tax: number;
        taxBasis?: number;
        optionId: string;
        optionValueId: string;
        priceAdjustments?: Array<CreateOrderPriceAdjustment>;
        productId: string;
    } & {
        [key: string]: any;
    };
    type Status = {
        code?: string;
        message?: string;
        status?: number;
    };
    type ProductListItemReference = {
        id?: string;
        priority?: number;
        product?: ProductReference;
        productList?: ProductListReference;
        public?: boolean;
        purchasedQuantity: number;
        quantity?: number;
        type?: string;
    };
    type Money = {
        currencyMnemonic?: string;
        value?: number;
    } & {
        [key: string]: any;
    };
    type SimpleSearchResult = {
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    type SearchRequest = {
        limit?: number;
        query: Query;
        sorts?: Array<Sort>;
        offset?: any;
    } & {
        [key: string]: any;
    };
    type PropertyDefinition = {
        defaultValue?: PropertyValueDefinition;
        id?: string;
        name: L10nString;
        description: L10nString;
        key?: boolean;
        localizable?: boolean;
        mandatory?: boolean;
        max?: number;
        minLength?: number;
        min?: number;
        multiValueType?: boolean;
        regularExpression?: string;
        scale?: number;
        searchable?: boolean;
        siteSpecific?: boolean;
        system?: boolean;
        unit?: L10nString;
        possibleValues?: Array<PropertyValueDefinition>;
        type: string;
        visible?: boolean;
    } & {
        [key: string]: any;
    };
    type LocalizedString = {} & {
        [key: string]: any;
    };
    type PaginatedSearchResult = {
        query: Query;
        sorts?: Array<Sort>;
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    type ClosedObject = {} & {
        [key: string]: any;
    };
    type OpenObject = {} & {
        [key: string]: any;
    };
    type NoPropertiesAllowed = {};
    type SpecifiedPropertiesAllowed = {} & {
        [key: string]: any;
    };
    type BoolFilter = {
        filters?: Array<Filter>;
        operator: string;
    } & {
        [key: string]: any;
    };
    type PaginatedSearchResultBase = {
        query: Query;
        sorts?: Array<Sort>;
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    type MatchAllQuery = {} & {
        [key: string]: any;
    };
    type FilteredQuery = {
        filter: Filter;
        query: Query;
    } & {
        [key: string]: any;
    };
    type QueryFilter = {
        query: Query;
    } & {
        [key: string]: any;
    };
    type Query = {
        boolQuery?: BoolQuery;
        filteredQuery?: FilteredQuery;
        matchAllQuery?: MatchAllQuery;
        nestedQuery?: NestedQuery;
        termQuery?: TermQuery;
        textQuery?: TextQuery;
    } & {
        [key: string]: any;
    };
    type TermQuery = {
        fields: Array<string>;
        operator: string;
        values?: Array<any>;
    } & {
        [key: string]: any;
    };
    type TermFilter = {
        field: string;
        operator: string;
        values?: Array<any>;
    } & {
        [key: string]: any;
    };
    type TextQuery = {
        fields: Array<string>;
        searchPhrase: string;
    } & {
        [key: string]: any;
    };
    type Range2Filter = {
        filterMode?: string;
        fromField: string;
        fromInclusive?: boolean;
        fromValue?: any;
        toField: string;
        toInclusive?: boolean;
        toValue?: any;
    } & {
        [key: string]: any;
    };
    type BoolQuery = {
        must?: Array<Query>;
        mustNot?: Array<Query>;
        should?: Array<Query>;
    } & {
        [key: string]: any;
    };
    type SimpleSearchResultBase = {
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    type NestedQuery = {
        path: string;
        query: Query;
        scoreMode?: string;
    } & {
        [key: string]: any;
    };
    type Filter = {
        boolFilter?: BoolFilter;
        queryFilter?: QueryFilter;
        range2Filter?: Range2Filter;
        rangeFilter?: RangeFilter;
        termFilter?: TermFilter;
    } & {
        [key: string]: any;
    };
    type Sort = {
        field: string;
        sortOrder?: string;
    } & {
        [key: string]: any;
    };
    type RangeFilter = {
        field: string;
        from?: any;
        fromInclusive?: boolean;
        to?: any;
        toInclusive?: boolean;
    } & {
        [key: string]: any;
    };
    type SearchRequestBase = {
        limit?: number;
        query: Query;
        sorts?: Array<Sort>;
        offset?: any;
    } & {
        [key: string]: any;
    };
    type MoneyMnemonic = {
        currencyMnemonic?: string;
        value?: number;
    } & {
        [key: string]: any;
    };
    type L10nString = {} & {
        [key: string]: any;
    };
    type AttributeDefinition = {
        defaultValue?: PropertyValueDefinition;
        id?: string;
        name: L10nString;
        description: L10nString;
        key?: boolean;
        localizable?: boolean;
        mandatory?: boolean;
        max?: number;
        minLength?: number;
        min?: number;
        multiValueType?: boolean;
        regularExpression?: string;
        scale?: number;
        searchable?: boolean;
        siteSpecific?: boolean;
        system?: boolean;
        unit?: L10nString;
        possibleValues?: Array<PropertyValueDefinition>;
        type: string;
        visible?: boolean;
    };
    type PropertyValueDefinition = {
        description: L10nString;
        displayValue: L10nString;
        id: string;
        position?: number;
        value: string;
    };
    type ChangeControlled = {
        creationDate?: any;
        modificationDate?: any;
        createdBy?: string;
        lastModifiedBy?: string;
    } & {
        [key: string]: any;
    };
    type ChangeControlledDataType = {
        creationDate?: any;
        modificationDate?: any;
        createdBy?: string;
        lastModifiedBy?: string;
    } & {
        [key: string]: any;
    };
    type Error = {
        type: string;
        title?: string;
        detail?: string;
        instance?: string;
    } & {
        [key: string]: any;
    };
}
/**
* [Orders](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=orders:Summary)
* ==================================
*
* *Manage order and order payment status.*<br />
*
*
* For instructions on how to retrieve access token for admin APIs: <a>https://developer.salesforce.com/docs/commerce/commerce-api/guide/authorization-for-admin-apis.html</a><br/><br/>
* Example with admin auth
*
* ```typescript
* import { Checkout, ClientConfig } from "commerce-sdk";
* // or
* const { Checkout, ClientConfig } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* token = { access_token: 'INSERT_ACCESS_TOKEN_HERE' };
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const ordersClient = new Checkout.Orders(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.4.4<br />
* Last Updated: <br />
* </span>

*

*/
export declare class Orders extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Returns the details of orders that match the query filters. By default, calling this API with no filter returns the 100 most recently created orders. To return up to 200 orders, use the limit parameter. To return a page of results past the first page, use a resource offset. *Note* : The sum of the offset and limit parameters cannot be greater than 10000.
    *
    * If you would like to get a raw Response object use the other getOrders function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param sortBy - Sort results by creation date or last modified date. The default is creation date.
    * @param sortOrder - Sort results in ascending or descending order. The default is descending.
    * @param status - Filter results by status. Valid statuses are 'new', 'completed', and 'cancelled'. You can include up to two statuses as a comma-separated string.
    * @param exportStatus - Filter results by export status. Valid export statuses are 'not_exported', 'exported', 'ready', and 'failed'. You can include up to three export statuses as a comma-separated string.
    * @param externalStatus - Filter results by external status.
    * @param confirmationStatus - Filter results by confirmation status. Valid confirmation statuses are 'confirmed' and 'not_confirmed'.
    * @param paymentStatus - Filter results by payment status. Valid payment statuses are 'not_paid', 'part_paid', and 'paid'. You can include up to two payment statuses as a comma-separated string.
    * @param shippingStatus - Filter results by shipping status. Valid shipping statuses are 'not_shipped', 'part_shipped', and 'shipped'. You can include up to two shipping statuses as a comma-separated string.
    * @param siteId -
    * @param offset -
    * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 100.
    * @param creationDateFrom - If passed, will return records where the `creationDate` is equal to or greater than the passed `datetime`.
    * @param creationDateTo - If passed, will return records where the `creationDate` is less than the passed `datetime`.
    * @param lastModifiedDateFrom - If passed, will return records where the `lastModifiedDate` is equal to or greater than the passed `datetime`.
    * @param lastModifiedDateTo - If passed, will return records where the `lastModifiedDate` is less than the passed `datetime`.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type Orders.OrdersResponse.
    *
    */
    getOrders(options?: {
        parameters?: {
            organizationId?: string;
            sortBy?: string;
            sortOrder?: string;
            status?: string;
            exportStatus?: string;
            externalStatus?: string;
            confirmationStatus?: string;
            paymentStatus?: string;
            shippingStatus?: string;
            siteId?: string;
            offset?: any;
            limit?: number;
            creationDateFrom?: any;
            creationDateTo?: any;
            lastModifiedDateFrom?: any;
            lastModifiedDateTo?: any;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }): Promise<Orders.OrdersResponse>;
    /**
    * Returns the details of orders that match the query filters. By default, calling this API with no filter returns the 100 most recently created orders. To return up to 200 orders, use the limit parameter. To return a page of results past the first page, use a resource offset. *Note* : The sum of the offset and limit parameters cannot be greater than 10000.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param sortBy - Sort results by creation date or last modified date. The default is creation date.
    * @param sortOrder - Sort results in ascending or descending order. The default is descending.
    * @param status - Filter results by status. Valid statuses are 'new', 'completed', and 'cancelled'. You can include up to two statuses as a comma-separated string.
    * @param exportStatus - Filter results by export status. Valid export statuses are 'not_exported', 'exported', 'ready', and 'failed'. You can include up to three export statuses as a comma-separated string.
    * @param externalStatus - Filter results by external status.
    * @param confirmationStatus - Filter results by confirmation status. Valid confirmation statuses are 'confirmed' and 'not_confirmed'.
    * @param paymentStatus - Filter results by payment status. Valid payment statuses are 'not_paid', 'part_paid', and 'paid'. You can include up to two payment statuses as a comma-separated string.
    * @param shippingStatus - Filter results by shipping status. Valid shipping statuses are 'not_shipped', 'part_shipped', and 'shipped'. You can include up to two shipping statuses as a comma-separated string.
    * @param siteId -
    * @param offset -
    * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 100.
    * @param creationDateFrom - If passed, will return records where the `creationDate` is equal to or greater than the passed `datetime`.
    * @param creationDateTo - If passed, will return records where the `creationDate` is less than the passed `datetime`.
    * @param lastModifiedDateFrom - If passed, will return records where the `lastModifiedDate` is equal to or greater than the passed `datetime`.
    * @param lastModifiedDateTo - If passed, will return records where the `lastModifiedDate` is less than the passed `datetime`.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Orders.OrdersResponse otherwise.
    *
    */
    getOrders<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            sortBy?: string;
            sortOrder?: string;
            status?: string;
            exportStatus?: string;
            externalStatus?: string;
            confirmationStatus?: string;
            paymentStatus?: string;
            shippingStatus?: string;
            siteId?: string;
            offset?: any;
            limit?: number;
            creationDateFrom?: any;
            creationDateTo?: any;
            lastModifiedDateFrom?: any;
            lastModifiedDateTo?: any;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : Orders.OrdersResponse>;
    /**
    * Use this endpoint whenever a fully calculated and paid or authorized order is created in any third-party system.

The endpoint can create an order on-the-fly in the Commerce Cloud platform by passing the order as JSON payload in the body of the POST request.

Other than the Basket API, this endpoint decouples any relation to other system domains, such as:

- Products
- Inventory
- Promotions
- Gift certificates
- Coupons

The order isn't treated differently than any other orders in the Commerce Cloud platform, and any status updates or order exports behave the same.

**Note**: For the custom attribute to be available for orders, configure it in Business Manager for both Basket and Order objects.

**Important**: This endpoint uses the `ShopperTokenTsob` security scheme. Always check the Security section of the endpoint documentation, which is hidden by default.

## Preconditions

The checkout must happen before making a request to this endpoint. That means that all sanity checks _are_ applied, the inventory _is_ reserved, the payment _is_ authorized, and the Basket _is_ fully calculated (including all promotions).

When meeting these conditions, it's possible to create the order in the Commerce Cloud platform.

## Decoupling

This endpoint can create an order with unknown products, with different pricing for known products, any unplanned price-adjustments (unrelated to the system's configured promotions), passing unknown payment, and shipping methods.

**Note**: There's no lookup or calculation, even if the passed object is configured in the platform.

## Still Coupled

The endpoint is still coupled to the following:

- the taxation policy (gross or net) is used from the site's preferences.
- the passed currency must be defined in the site.

## Calculation

There's no multiplying or dividing operations performed by the platform on this order.

The following fields are summed up during runtime on the platform:

**Order Level**

- `adjustedMerchandizeTotalTax`
- `adjustedShippingTotalTax`
- `merchandizeTotalTax`
- `adjustedTax`
- `productSubTotal`
- `productTotal`
- `shippingTotalTax`
- `orderTotal`
- `taxTotal`

**Line Item Level**

- `priceAfterItemDiscount`
- `priceAfterOrderDiscount`
- `adjustedTax`

**Shipment**

- `merchandizeTotalTax`
- `productSubTotal`
- `productTotal`
- `shippingTotalTax`

To make sure the fields are summed up correctly, the passed `orderTotal` and `taxTotal` are compared to the platform's summed up `orderTotal` and `taxTotal`.

An `InvalidOrderTotalException` or `InvalidTaxTotalException` is thrown if the calculation doesn't match.

The `orderTotal` and `taxTotal` are calculated as follows:

- `orderTotal` = sum(`ProductLineItems.grossPrice`) + sum(`Shipments.shipmentTotal`) - sum(`ProductLineItems.PriceAdjustments.grossPrice` + `Order.PriceAdjustments.grossPrice`)
- `taxTotal` = sum (`ProductLineItems.tax`) + sum(`Shipments.taxTotal`) - sum(`ProductLineItems.PriceAdjustments.tax` + `Order.PriceAdjustments.tax`)

## Order Status

The order is automatically placed after creation.

The payment status can be set via payload.

All other status can be set via PATCH `orders/\{orderNo\}/status`.

    *
    * If you would like to get a raw Response object use the other createOrders function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    createOrders(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.CreateOrderRequest;
    }): Promise<void>;
    /**
    * Use this endpoint whenever a fully calculated and paid or authorized order is created in any third-party system.

The endpoint can create an order on-the-fly in the Commerce Cloud platform by passing the order as JSON payload in the body of the POST request.

Other than the Basket API, this endpoint decouples any relation to other system domains, such as:

- Products
- Inventory
- Promotions
- Gift certificates
- Coupons

The order isn't treated differently than any other orders in the Commerce Cloud platform, and any status updates or order exports behave the same.

**Note**: For the custom attribute to be available for orders, configure it in Business Manager for both Basket and Order objects.

**Important**: This endpoint uses the `ShopperTokenTsob` security scheme. Always check the Security section of the endpoint documentation, which is hidden by default.

## Preconditions

The checkout must happen before making a request to this endpoint. That means that all sanity checks _are_ applied, the inventory _is_ reserved, the payment _is_ authorized, and the Basket _is_ fully calculated (including all promotions).

When meeting these conditions, it's possible to create the order in the Commerce Cloud platform.

## Decoupling

This endpoint can create an order with unknown products, with different pricing for known products, any unplanned price-adjustments (unrelated to the system's configured promotions), passing unknown payment, and shipping methods.

**Note**: There's no lookup or calculation, even if the passed object is configured in the platform.

## Still Coupled

The endpoint is still coupled to the following:

- the taxation policy (gross or net) is used from the site's preferences.
- the passed currency must be defined in the site.

## Calculation

There's no multiplying or dividing operations performed by the platform on this order.

The following fields are summed up during runtime on the platform:

**Order Level**

- `adjustedMerchandizeTotalTax`
- `adjustedShippingTotalTax`
- `merchandizeTotalTax`
- `adjustedTax`
- `productSubTotal`
- `productTotal`
- `shippingTotalTax`
- `orderTotal`
- `taxTotal`

**Line Item Level**

- `priceAfterItemDiscount`
- `priceAfterOrderDiscount`
- `adjustedTax`

**Shipment**

- `merchandizeTotalTax`
- `productSubTotal`
- `productTotal`
- `shippingTotalTax`

To make sure the fields are summed up correctly, the passed `orderTotal` and `taxTotal` are compared to the platform's summed up `orderTotal` and `taxTotal`.

An `InvalidOrderTotalException` or `InvalidTaxTotalException` is thrown if the calculation doesn't match.

The `orderTotal` and `taxTotal` are calculated as follows:

- `orderTotal` = sum(`ProductLineItems.grossPrice`) + sum(`Shipments.shipmentTotal`) - sum(`ProductLineItems.PriceAdjustments.grossPrice` + `Order.PriceAdjustments.grossPrice`)
- `taxTotal` = sum (`ProductLineItems.tax`) + sum(`Shipments.taxTotal`) - sum(`ProductLineItems.PriceAdjustments.tax` + `Order.PriceAdjustments.tax`)

## Order Status

The order is automatically placed after creation.

The payment status can be set via payload.

All other status can be set via PATCH `orders/\{orderNo\}/status`.

    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    createOrders<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.CreateOrderRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Returns the details of the order with the specified order number.
    *
    * If you would like to get a raw Response object use the other getOrder function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type Orders.Order.
    *
    */
    getOrder(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }): Promise<Orders.Order>;
    /**
    * Returns the details of the order with the specified order number.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Orders.Order otherwise.
    *
    */
    getOrder<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : Orders.Order>;
    /**
    * Updates the order.
    *
    * If you would like to get a raw Response object use the other updateOrder function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrder(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the order.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrder<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order confirmation status.
    *
    * If you would like to get a raw Response object use the other updateOrderConfirmationStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderConfirmationStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderConfirmationStatusUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the order confirmation status.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderConfirmationStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderConfirmationStatusUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order export status. If on-order inventory is turned on for the associated inventory list, then setting the export status to EXPORTED finalizes on-order inventory transactions for this order by changing their type from on-order to final.
    *
    * If you would like to get a raw Response object use the other updateOrderExportStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderExportStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderExportStatusUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the order export status. If on-order inventory is turned on for the associated inventory list, then setting the export status to EXPORTED finalizes on-order inventory transactions for this order by changing their type from on-order to final.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderExportStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderExportStatusUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order external status.
    *
    * If you would like to get a raw Response object use the other updateOrderExternalStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderExternalStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderExternalStatusUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the order external status.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderExternalStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderExternalStatusUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order payment status.
    *
    * If you would like to get a raw Response object use the other updateOrderPaymentStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderPaymentStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderPaymentStatusUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the order payment status.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderPaymentStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderPaymentStatusUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order shipping status.
    *
    * If you would like to get a raw Response object use the other updateOrderShippingStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderShippingStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderShippingStatusUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the order shipping status.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderShippingStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderShippingStatusUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order status. Orders in status NEW, COMPLETED or CANCELLED can't be changed to status CREATED or FAILED.

Changing the status processes different actions on inventory, coupons, wishlists and the order itself. Here are the supported actions:

- Fail Order: Release inventory and remove coupon redemptions. (CREATED -\> FAILED)
- Fail Order With Reopen Basket: Release inventory, remove coupon redemptions, and reopen the basket, if applicable. A basket can only be
reopened if no other basket for the customer exists at the moment of failing the order since a customer is limited to 1 storefront basket at a
time.  (CREATED -\> FAILED)
- Undo Fail Order: Reserve inventory and recreate coupon redemptions. (FAILED -\> CREATED)
- Place Order: Generate Shipment and Invoice numbers. (CREATED -\> NEW, COMPLETED or CANCELLED)
- Cancel Order: Release inventory, remove wishlist purchases, and remove coupon redemptions. (NEW, COMPLETED -\> CANCELLED)
- Undo Cancel Order: Reserve inventory, add wishlist purchases, and recreate coupon redemptions. (CANCELLED -\> NEW, COMPLETED)

Actions can fail for example when inventory is not available anymore.
    *
    * If you would like to get a raw Response object use the other updateOrderStatus function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void | void.
    *
    */
    updateOrderStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderStatusUpdateRequest;
    }): Promise<void | void>;
    /**
    * Updates the order status. Orders in status NEW, COMPLETED or CANCELLED can't be changed to status CREATED or FAILED.

Changing the status processes different actions on inventory, coupons, wishlists and the order itself. Here are the supported actions:

- Fail Order: Release inventory and remove coupon redemptions. (CREATED -\> FAILED)
- Fail Order With Reopen Basket: Release inventory, remove coupon redemptions, and reopen the basket, if applicable. A basket can only be
reopened if no other basket for the customer exists at the moment of failing the order since a customer is limited to 1 storefront basket at a
time.  (CREATED -\> FAILED)
- Undo Fail Order: Reserve inventory and recreate coupon redemptions. (FAILED -\> CREATED)
- Place Order: Generate Shipment and Invoice numbers. (CREATED -\> NEW, COMPLETED or CANCELLED)
- Cancel Order: Release inventory, remove wishlist purchases, and remove coupon redemptions. (NEW, COMPLETED -\> CANCELLED)
- Undo Cancel Order: Reserve inventory, add wishlist purchases, and recreate coupon redemptions. (CANCELLED -\> NEW, COMPLETED)

Actions can fail for example when inventory is not available anymore.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void | void otherwise.
    *
    */
    updateOrderStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.OrderStatusUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void | void>;
    /**
    * Updates the payment instrument of an order.
    *
    * If you would like to get a raw Response object use the other updateOrderPaymentInstrument function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param paymentInstrumentId - ID of the payment instrument.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderPaymentInstrument(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.PaymentInstrumentUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the payment instrument of an order.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param paymentInstrumentId - ID of the payment instrument.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderPaymentInstrument<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.PaymentInstrumentUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the transaction of an order payment instrument.
    *
    * If you would like to get a raw Response object use the other updateOrderPaymentTransaction function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param paymentInstrumentId - ID of the payment instrument.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderPaymentTransaction(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.PaymentTransactionUpdateRequest;
    }): Promise<void>;
    /**
    * Updates the transaction of an order payment instrument.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param paymentInstrumentId - ID of the payment instrument.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderPaymentTransaction<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.PaymentTransactionUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Creates or replaces the shipping address.
    *
    * If you would like to get a raw Response object use the other updateOrderShippingAddress function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param shipmentId - ID of the shipment.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type void.
    *
    */
    updateOrderShippingAddress(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            shipmentId: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.ShippingAddressUpdateRequest;
    }): Promise<void>;
    /**
    * Creates or replaces the shipping address.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param orderNo - The order number.
    * @param shipmentId - ID of the shipment.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    updateOrderShippingAddress<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            shipmentId: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: Orders.ShippingAddressUpdateRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
}
