import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import type { OperationOptions } from "retry";
import type { RequestInit } from "node-fetch";
export declare namespace SourceCodeGroups {
    export type SourceCodeGroup = {
        active?: boolean;
        activeRedirect?: SourceCodeRedirectInfo;
        cookieDuration?: number;
        creationDate?: any;
        description?: string;
        enabled?: boolean;
        endTime?: any;
        id: string;
        inactiveRedirect?: SourceCodeRedirectInfo;
        lastModified?: any;
        specifications?: Array<SourceCodeSpecification>;
        startTime?: any;
    } & {
        [key: string]: any;
    };
    export type SourceCodeGroupSearchResult = {
        hits: Array<SourceCodeGroup>;
        query: Query;
        sorts?: Array<Sort>;
        limit: number;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    export type SourceCodeRedirectInfo = {
        locationType: string;
    } & {
        [key: string]: any;
    };
    export type SourceCodeSpecification = {
        expression: string;
    } & {
        [key: string]: any;
    };
    export type ErrorResponse = {
        type: string;
        title?: string;
        detail?: string;
        instance?: string;
    } & {
        [key: string]: any;
    };
    export type ChangeControlled = {
        creationDate?: any;
        modificationDate?: any;
        createdBy?: string;
        lastModifiedBy?: string;
    } & {
        [key: string]: any;
    };
    type RangeFilter = {};
    export type ChangeControlledDataType = {
        creationDate?: any;
        modificationDate?: any;
        createdBy?: string;
        lastModifiedBy?: string;
    } & {
        [key: string]: any;
    };
    export type Error = {
        type: string;
        title?: string;
        detail?: string;
        instance?: string;
    } & {
        [key: string]: any;
    };
    export type Money = {
        currencyMnemonic?: string;
        value?: number;
    } & {
        [key: string]: any;
    };
    export type SimpleSearchResult = {
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    export type SearchRequest = {
        limit?: number;
        query: Query;
        sorts?: Array<Sort>;
        offset?: any;
    } & {
        [key: string]: any;
    };
    export type PropertyDefinition = {
        defaultValue?: PropertyValueDefinition;
        id?: string;
        name: L10nString;
        description: L10nString;
        key?: boolean;
        localizable?: boolean;
        mandatory?: boolean;
        max?: number;
        minLength?: number;
        min?: number;
        multiValueType?: boolean;
        regularExpression?: string;
        scale?: number;
        searchable?: boolean;
        siteSpecific?: boolean;
        system?: boolean;
        unit?: L10nString;
        possibleValues?: Array<PropertyValueDefinition>;
        type: string;
        visible?: boolean;
    } & {
        [key: string]: any;
    };
    export type LocalizedString = {} & {
        [key: string]: any;
    };
    export type PaginatedSearchResult = {
        query: Query;
        sorts?: Array<Sort>;
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    export type ClosedObject = {} & {
        [key: string]: any;
    };
    export type OpenObject = {} & {
        [key: string]: any;
    };
    export type NoPropertiesAllowed = {};
    export type SpecifiedPropertiesAllowed = {} & {
        [key: string]: any;
    };
    export type BoolFilter = {
        filters?: Array<Filter>;
        operator: string;
    } & {
        [key: string]: any;
    };
    export type PaginatedSearchResultBase = {
        query: Query;
        sorts?: Array<Sort>;
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    export type MatchAllQuery = {} & {
        [key: string]: any;
    };
    export type FilteredQuery = {
        filter: Filter;
        query: Query;
    } & {
        [key: string]: any;
    };
    export type QueryFilter = {
        query: Query;
    } & {
        [key: string]: any;
    };
    export type Query = {
        boolQuery?: BoolQuery;
        filteredQuery?: FilteredQuery;
        matchAllQuery?: MatchAllQuery;
        nestedQuery?: NestedQuery;
        termQuery?: TermQuery;
        textQuery?: TextQuery;
    } & {
        [key: string]: any;
    };
    export type TermQuery = {
        fields: Array<string>;
        operator: string;
        values?: Array<any>;
    } & {
        [key: string]: any;
    };
    export type TermFilter = {
        field: string;
        operator: string;
        values?: Array<any>;
    } & {
        [key: string]: any;
    };
    export type TextQuery = {
        fields: Array<string>;
        searchPhrase: string;
    } & {
        [key: string]: any;
    };
    export type Range2Filter = {
        filterMode?: string;
        fromField: string;
        fromInclusive?: boolean;
        fromValue?: any;
        toField: string;
        toInclusive?: boolean;
        toValue?: any;
    } & {
        [key: string]: any;
    };
    export type BoolQuery = {
        must?: Array<Query>;
        mustNot?: Array<Query>;
        should?: Array<Query>;
    } & {
        [key: string]: any;
    };
    export type SimpleSearchResultBase = {
        limit: number;
        hits?: Array<object>;
        offset: any;
        total: any;
    } & {
        [key: string]: any;
    };
    export type NestedQuery = {
        path: string;
        query: Query;
        scoreMode?: string;
    } & {
        [key: string]: any;
    };
    export type Filter = {
        boolFilter?: BoolFilter;
        queryFilter?: QueryFilter;
        range2Filter?: Range2Filter;
        rangeFilter?: RangeFilter;
        termFilter?: TermFilter;
    } & {
        [key: string]: any;
    };
    export type Sort = {
        field: string;
        sortOrder?: string;
    } & {
        [key: string]: any;
    };
    export type SearchRequestBase = {
        limit?: number;
        query: Query;
        sorts?: Array<Sort>;
        offset?: any;
    } & {
        [key: string]: any;
    };
    export type MoneyMnemonic = {
        currencyMnemonic?: string;
        value?: number;
    } & {
        [key: string]: any;
    };
    export type L10nString = {} & {
        [key: string]: any;
    };
    export type AttributeDefinition = {
        defaultValue?: PropertyValueDefinition;
        id?: string;
        name: L10nString;
        description: L10nString;
        key?: boolean;
        localizable?: boolean;
        mandatory?: boolean;
        max?: number;
        minLength?: number;
        min?: number;
        multiValueType?: boolean;
        regularExpression?: string;
        scale?: number;
        searchable?: boolean;
        siteSpecific?: boolean;
        system?: boolean;
        unit?: L10nString;
        possibleValues?: Array<PropertyValueDefinition>;
        type: string;
        visible?: boolean;
    };
    export type PropertyValueDefinition = {
        description: L10nString;
        displayValue: L10nString;
        id: string;
        position?: number;
        value: string;
    };
    export {};
}
/**
* [Source Code Groups](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=source-code-groups:Summary)
* ==================================
*
* *Create, update, delete, and search for source code groups.*<br />
*
*
* For instructions on how to retrieve access token for admin APIs: <a>https://developer.salesforce.com/docs/commerce/commerce-api/guide/authorization-for-admin-apis.html</a><br/><br/>
* Example with admin auth
*
* ```typescript
* import { Pricing, ClientConfig } from "commerce-sdk";
* // or
* const { Pricing, ClientConfig } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* token = { access_token: 'INSERT_ACCESS_TOKEN_HERE' };
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const sourceCodeGroupsClient = new Pricing.SourceCodeGroups(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.27<br />
* Last Updated: <br />
* </span>

*

*/
export declare class SourceCodeGroups extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Deletes the source code group by ID.
    *
    * If you would like to get a raw Response object use the other deleteSourceCodeGroup function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type void.
    *
    */
    deleteSourceCodeGroup(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Deletes the source code group by ID.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
    deleteSourceCodeGroup<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action to retrieve source code group information.
    *
    * If you would like to get a raw Response object use the other getSourceCodeGroup function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type SourceCodeGroups.SourceCodeGroup.
    *
    */
    getSourceCodeGroup(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }): Promise<SourceCodeGroups.SourceCodeGroup>;
    /**
    * Action to retrieve source code group information.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroups.SourceCodeGroup otherwise.
    *
    */
    getSourceCodeGroup<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroups.SourceCodeGroup>;
    /**
    * Updates the source code group with the specified information.
    *
    * If you would like to get a raw Response object use the other updateSourceCodeGroup function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type SourceCodeGroups.SourceCodeGroup.
    *
    */
    updateSourceCodeGroup(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroups.SourceCodeGroup;
    }): Promise<SourceCodeGroups.SourceCodeGroup>;
    /**
    * Updates the source code group with the specified information.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroups.SourceCodeGroup otherwise.
    *
    */
    updateSourceCodeGroup<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroups.SourceCodeGroup;
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroups.SourceCodeGroup>;
    /**
    * Creates a source code group using the information provided.
    *
    * If you would like to get a raw Response object use the other createSourceCodeGroup function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type SourceCodeGroups.SourceCodeGroup.
    *
    */
    createSourceCodeGroup(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroups.SourceCodeGroup;
    }): Promise<SourceCodeGroups.SourceCodeGroup>;
    /**
    * Creates a source code group using the information provided.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param id - The ID of the source code group to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroups.SourceCodeGroup otherwise.
    *
    */
    createSourceCodeGroup<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroups.SourceCodeGroup;
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroups.SourceCodeGroup>;
    /**
    * Searches for source code groups.
 
The query attribute specifies a complex query that can be used to narrow down the search with the following searchable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | sourceCode | String |
  | startTime | DateTime |
  | endTime | DateTime |
  | creationDate | DateTime |
  | enabled | Boolean |
  | active | Boolean |
  
The sourceCode and active fields can only be used in Queries as conjunctions (using AND). If the field is used in a disjunction
(OR) an exception will be thrown.

The output of the query can also be sorted, with the following sortable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | enabled | Boolean |
  | creationDate | DateTime |

    *
    * If you would like to get a raw Response object use the other sourceCodeGroupsSearch function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type SourceCodeGroups.SourceCodeGroupSearchResult.
    *
    */
    sourceCodeGroupsSearch(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroups.SearchRequest;
    }): Promise<SourceCodeGroups.SourceCodeGroupSearchResult>;
    /**
    * Searches for source code groups.
 
The query attribute specifies a complex query that can be used to narrow down the search with the following searchable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | sourceCode | String |
  | startTime | DateTime |
  | endTime | DateTime |
  | creationDate | DateTime |
  | enabled | Boolean |
  | active | Boolean |
  
The sourceCode and active fields can only be used in Queries as conjunctions (using AND). If the field is used in a disjunction
(OR) an exception will be thrown.

The output of the query can also be sorted, with the following sortable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | enabled | Boolean |
  | creationDate | DateTime |

    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroups.SourceCodeGroupSearchResult otherwise.
    *
    */
    sourceCodeGroupsSearch<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        } & {
            [key in `c_${string}`]: any;
        };
        retrySettings?: OperationOptions;
        fetchOptions?: RequestInit;
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroups.SearchRequest;
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroups.SourceCodeGroupSearchResult>;
}
